@@ -1,7 +1,7 @@
 import os
 import sqlite3
 
-from utils import get_config_directory
+from tasq_cli.utils import get_config_directory
 
 
 class UploadsDatabase:
