@@ -74,7 +74,7 @@ def upload_file(dataset_name, db, settings, client, file_name_with_path, leaf_pa
                     # TODO this is questionable
                     # we might not want to make these
                     # public in the long term
-                    ACL='public-read'
+                    # ACL='public-read'
                     # NOTE
                     # consider that sync might work faster than put_object
                 )
